import "src/head.js";
import "src/core.js";
import "src/config.js";
import "src/scale.js";
import "src/domain.js";
import "src/data.js";
import "src/data.convert.js";
import "src/data.load.js";
import "src/category.js";
import "src/interaction.js";
import "src/size.js";
import "src/shape.js";
import "src/shape.line.js";
import "src/shape.bar.js";
import "src/text.js";
import "src/type.js";
import "src/grid.js";
import "src/tooltip.js";
import "src/legend.js";
import "src/title.js";
import "src/axis.js";
import "src/clip.js";
import "src/arc.js";
import "src/region.js";
import "src/drag.js";
import "src/selection.js";
import "src/subchart.js";
import "src/zoom.js";
import "src/color.js";
import "src/format.js";
import "src/cache.js";
import "src/class.js";
import "src/util.js";
import "src/api.focus.js";
import "src/api.show.js";
import "src/api.zoom.js";
import "src/api.load.js";
import "src/api.flow.js";
import "src/api.selection.js";
import "src/api.transform.js";
import "src/api.group.js";
import "src/api.grid.js";
import "src/api.region.js";
import "src/api.data.js";
import "src/api.category.js";
import "src/api.color.js";
import "src/api.x.js";
import "src/api.axis.js";
import "src/api.legend.js";
import "src/api.chart.js";
import "src/api.tooltip.js";
import "src/c3.axis.js";
import "src/ua.js";
import "src/polyfill.js";
import "src/tail.js";
